/// <reference types="mongodb" />
import { Document, Model } from "mongoose";
import { ObjectId } from "bson";
export declare class JobQueue<T> {
    private lastUsedTick;
    readonly model: Model<Job<T>>;
    constructor(collectionName: string);
    private getVersion;
    add(payload: T): Promise<Job<T>>;
    take(processTime: number): Promise<Job<T>>;
    markFinished(_id: ObjectId): Promise<void>;
    get(_id: ObjectId): Promise<IJob<T>>;
    clear(): Promise<{
        ok?: number;
        n?: number;
    }>;
    waitingJobsCount(): Promise<number>;
}
export interface IJob<T> {
    createdOn: Date;
    received: boolean;
    version: number;
    payload: T;
    startedOn: Date;
    timeoutOn: Date;
    finishedOn: Date;
}
export declare type JobState = 'queued' | 'processing' | 'timeout' | 'finished';
export declare function getJobState(job: IJob<any>): JobState;
export interface Job<T> extends Document, IJob<T> {
}
